do need to be careful that, when shutting down, the offline state plugin does its upload at the very last moment...
    otherwise stuff like the git_status plugin, which creates state during shutdown, won't have their state saved.
